PetBattleLiteFrame = LibStub("AceAddon-3.0"):NewAddon("PetBattleLiteFrame", "AceConsole-3.0", "AceEvent-3.0" );

local MAX_ACTIVE_PETS = 3;

local options = {
	name = "Pet Battle Lite Frame",
	handler = PetBattleLiteFrame,
	type = "group",
	args = {
		showTrack = {
			type = "toggle",
			name = "Only show when tracking",
			desc = "Shows the frame only when you are tracking Pet Battles on the minimap, hides it when the tracking is disabled",
			order = 1,
			get = "GetToggle",
			set = "SetToggle",
		},
		scale = {
			type = "range",
			name = "Set Scale",
			desc = "Sets the scale of the frame",
			min = 0.3, max = 2, step = 0.01,
			get = function()
				return PetBattleLiteFrame.db.profile.scale
			end,
			set = function(info, value)
				PetBattleLiteFrame.db.profile.scale = value
				PetBattleLiteFrame:Update()
			end,
		},
	}
}
		

local defaults = {
	profile = {
		showTrack = false,
		scale = 1,
	}
}

function PetBattleLiteFrame:OnInitialize()
	self.db = LibStub("AceDB-3.0"):New("PetBattleLiteFrameSaved", defaults)
	LibStub("AceConfig-3.0"):RegisterOptionsTable("PetBattleLiteFrame", options)
	self.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("PetBattleLiteFrame", "Pet Battle Lite Frame")
	self:Print("Loaded")
end

function PetBattleLiteFrame:OnEnable()
	self:RegisterEvent("PET_JOURNAL_PETS_HEALED", "Update")
	self:RegisterEvent("PET_JOURNAL_LIST_UPDATE", "Update")
	self:RegisterEvent("PET_BATTLE_CLOSE", "Update")
	self:RegisterEvent("PET_BATTLE_OPENING_START", "Update")
	self:RegisterEvent("BATTLE_PET_CURSOR_CLEAR", "Update")
	self:RegisterEvent("QUEST_LOG_UPDATE", "Update")
	self:RegisterEvent("ZONE_CHANGED_NEW_AREA", "Update")
	self:RegisterEvent("MINIMAP_UPDATE_TRACKING", "Update")
	PBLFParent:Hide()
end	

function PetBattleLiteFrame:Update(event, ...)

	-- Hide if we're in an instance. There's no pet battles in instances. Yet.
	if(event == "PET_BATTLE_OPENING_START" or IsInInstance()) then
		PBLFParent:Hide()
		return
	end
	
	-- Check to see if we're tracking pets
	if(self.db.profile.showTrack) then
		for i = 1, GetNumTrackingTypes() do
			local name, _, active = GetTrackingInfo(i)
			if(name == "Track Pets") then
				if(active == nil) then -- why it returns 1 for true and nil for false beats me
					self:Print("hidden")
					PBLFParent:Hide()
					return
				end
			end
		end
	end
		
	-- Update the frames	
	for i = 1,MAX_ACTIVE_PETS do
	
		local petframe = PBLFParent["Pet"..i];
		local petID = C_PetJournal.GetPetLoadOutInfo(i)
		
		if(petID) then
			local hp, maxhp, _, _, rarity = C_PetJournal.GetPetStats(petID)
			petframe.hp:SetMinMaxValues(0, maxhp)
			petframe.hp:SetValue(hp)
			petframe.hp.text:SetText(hp.."/"..maxhp)
			petframe.isDead:SetShown(hp <= 0)
			
			local speciesID, customName, level, xp, maxXp, displayID, isFavorite, name, icon, petType, creatureID = C_PetJournal.GetPetInfoByPetID(petID)
			petframe.xp:SetMinMaxValues(0, maxXp)
			petframe.xp:SetValue(xp)
			petframe.xp.text:SetText(xp.."/"..maxXp)
			petframe.level:SetText(level)
			petframe.name:SetText(customName or name)
			petframe.icon:SetTexture(icon)
			petframe.qualityBorder:SetVertexColor(ITEM_QUALITY_COLORS[rarity-1].r, ITEM_QUALITY_COLORS[rarity-1].g, ITEM_QUALITY_COLORS[rarity-1].b)
			
			petframe.petID = petID
			
			petframe:Show()
			
			if (event == "QUEST_LOG_UPDATE") then
				self:UnregisterEvent("QUEST_LOG_UPDATE") -- why can't i just get pet info on PLAYER_LOGIN like normal people
				LoadAddOn("Blizzard_PetJournal") -- Because this won't work properly at the start either
			end
		else
			petframe:Hide()
		end
	end
	
	-- Show the frame if everything was successful
	PBLFParent:SetScale(self.db.profile.scale)
	PBLFParent:Show()
end

function LFPetJournalPetLoadoutDragButton_OnClick(self, button)
	loadout = self:GetParent()
	if (button == "RightButton" and loadout.petID) then
		PetJournal_ShowPetDropdown(nil, self, 0, 0, loadout.petID)
	end
	
	local type, petID = GetCursorInfo()
	if type == "battlepet" then
		local _, dialog = StaticPopup_Visible("BATTLE_PET_RELEASE")
		if ( dialog and dialog.data == petID ) then
			StaticPopup_Hide("BATTLE_PET_RELEASE")
		end
		
		C_PetJournal.SetPetLoadOutInfo(self:GetParent():GetID(), petID)
		ClearCursor();
	end
end

function LFPetJournalDragButton_OnDragStart(self)
	if (not self:GetParent().petID) then
		return;
	end

	PetJournal_HidePetDropdown();
	C_PetJournal.PickupPet(self:GetParent().petID, PetJournal.isWild)
	
	for i=1,MAX_ACTIVE_PETS do
		local loadoutPlate = PetJournal.Loadout["Pet"..i];
		local petID, ability1ID, ability2ID, ability3ID, locked = C_PetJournal.GetPetLoadOutInfo(i)
		if(locked) then
			PetJournal.Loadout["Pet"..i].setButton:Hide()
		else
			PetJournal.Loadout["Pet"..i].setButton:Show()
		end
	end
end

function PetBattleLiteFrame:GetToggle(info)
	return self.db.profile[info[#info]]
end

function PetBattleLiteFrame:SetToggle(info)
	if(self.db.profile[info[#info]]) then
		self.db.profile[info[#info]] = false
	else
		self.db.profile[info[#info]] = true
	end
	PetBattleLiteFrame:Update()
end